#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 transformers-compat
version:              0.7
visibility:           public
id:                   transformers-compat-0.7-DEkprM8uNQhJDKKPf6L2ns
key:                  transformers-compat-0.7-DEkprM8uNQhJDKKPf6L2ns
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/transformers-compat/
synopsis:             A small compatibility shim for the transformers library
description:
    This package includes backported versions of types that were added
    to transformers in transformers 0.3, 0.4, and 0.5 for users who need strict
    transformers 0.2 or 0.3 compatibility to run on old versions of the
    platform, but also need those types.

    Those users should be able to just depend on @transformers >= 0.2@
    and @transformers-compat >= 0.3@.

    Note: missing methods are not supplied, but this at least permits the types to be used.

category:             Compatibility
abi:                  48a85c6ed7e22b7e09e4c33406cc3036
exposed:              True
exposed-modules:
    Control.Monad.Trans.Instances Data.Functor.Classes.Generic
    Data.Functor.Classes.Generic.Internal

hidden-modules:       Paths_transformers_compat
import-dirs:          /usr/lib/ghc-8.10.5/site-local/transformers-compat-0.7
library-dirs:         /usr/lib/ghc-8.10.5/site-local/transformers-compat-0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/transformers-compat-0.7
hs-libraries:         HStransformers-compat-0.7-DEkprM8uNQhJDKKPf6L2ns
depends:              base-4.14.2.0 ghc-prim-0.6.1 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-transformers-compat/html/transformers-compat.haddock

haddock-html:         /usr/share/doc/haskell-transformers-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

